JobTimer

Struct JobTimer 

pub struct JobTimer { /* private fields */ }
Tracks time for jobs that run on many threads.

Meant for use with a threadpool. For example, build timing for each unit of work submitted to something like rayon and accumulate them here.

Currently not threadsafe, meant to be used by a central orchestrator because that happens to be what fontc does.

Implementations

Source

impl JobTimer

pub fn new() -> Self

Prepare to time things using the provided time zero.

pub fn create_timer(&self, id: AnyWorkId, nth_wave: usize) -> JobTime

Start timing a job.

Meant to be called when a job is runnable, that is it’s ready to be submitted to an execution system such as a threadpool.

nth_wave shows on mouseover in the final output. Each time we release a group of jobs - because their dependencies are complate - we increment it so one can see the graph progression in the timing svg output.

pub fn add(&mut self, timing: JobTime)

pub fn write_svg(&mut self, out: &mut impl Write) -> Result<(), Error>